/*
 * This file is part of con4gis, the gis-kit for Contao CMS.
 * @package con4gis
 * @version 8
 * @author con4gis contributors (see "authors.txt")
 * @license LGPL-3.0-or-later
 * @copyright (c) 2010-2022, by Küstenschmiede GmbH Software & Design
 * @link https://www.con4gis.org
 */

import React, {Component, Suspense} from "react";
const Titlebar = React.lazy(() => import("./c4g-titlebar.jsx"));
import {getLanguage} from "../c4g-maps-i18n";
import {Control} from "ol/control";
import {utils} from "../c4g-maps-utils";

export default class Infopage extends Component {

  constructor(props) {
    super(props);

    const scope = this;
    // create control to toggle the panel
    let element = document.createElement('div');
    let button = document.createElement('button');
    this.langConstants = getLanguage(props.mapController.data);

    if (props.mapController.data.themeData && props.mapController.data.themeData.controlLabels) {
      let span = document.createElement('span');
      span.innerText = this.langConstants.CTRL_INFOAREA;
      button.appendChild(span);
    }
    else {
      button.title = this.langConstants.CTRL_INFOAREA;
    }

    element.className = "c4g-infopage-control ol-unselectable ol-control ";
    if (props.open) {
      element.className += "c4g-open";
    } else {
      element.className += "c4g-close";
    }
    if (props.external) {
      element.className += " c4g-external";
    }
    element.appendChild(button);
    jQuery(element).on('click', function (event) {
      if (scope.state.open) {
        scope.close();
      } else {
        scope.open();
      }
    });
    let mapController = props.mapController;
    let control = new Control({element: element, target: props.target});
    let index = mapController.arrComponents.findIndex(element => element.name === "legend");
    if (index && mapController.arrComponents[index]) {
      mapController.arrComponents[index].control = control;
      mapController.mapsControls.controls.infoPage = control;
    } else {
      mapController.map.addControl(control);
    }

    this.close = this.close.bind(this);
    this.open = this.open.bind(this);
    this.state = {
      open: props.open || false,
      control: control
    }
  }

  render() {
    if (this.state.open) {
      jQuery(this.state.control.element).addClass("c4g-open").removeClass("c4g-close");
      jQuery(".c4g-infopage-container").addClass("c4g-open").removeClass("c4g-close");
    } else {
      jQuery(this.state.control.element).removeClass("c4g-open").addClass("c4g-close");
      jQuery(".c4g-infopage-container").removeClass("c4g-open").addClass("c4g-close");
    }
    
    return (
      <div className={"c4g-infopage-wrapper"}>
        <Suspense fallback={<div>Loading...</div>}>
          <Titlebar wrapperClass={"c4g-infopage-header"} headerClass={"c4g-infopage-headline"}
                    header={this.langConstants.INFOPAGE} closeBtnClass={"c4g-titlebar-close"} closeBtnCb={this.close} closeBtnTitle={this.langConstants.CLOSE}>
          </Titlebar>
        </Suspense>
        <div className={"c4g-infopage-content"} dangerouslySetInnerHTML={{__html: this.props.infoContent}}>
        </div>
      </div>
    );
  }

  open() {
    this.setState({open: true});
    this.props.mapController.setOpenComponent(this);
  }

  close() {
    this.setState({open: false});
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if (this.props.mapController.data.caching) {
      let panelVal = utils.getValue('panel');
      if (panelVal === "Infopage" && !this.state.open) {
        utils.storeValue('panel', "");
      }
      else if (panelVal !== "Infopage" && this.state.open) {
        utils.storeValue('panel', "Infopage")
      }
    }
  }

}